import javax.microedition.midlet.*;
import javax.microedition.lcdui.*;

/**
 * A MIDlet that demonstrates how to use the CommandListener interface in
 * order to capture command events when triggerd by the user (such as when they
 * hit OK on a command item).
 *
 * @author Martin J. Wells
 */
public class CommandListenTest extends MIDlet implements CommandListener
{
   private Form form;         // form we'll display
   private Command quit;      // quit command added to form


   /**
    * Constructor for the MIDlet which instantiates the Form object then
    * populates it with a string and a "Quit" command.
    */
   public CommandListenTest()
   {
      // Setup the UI
      form = new Form("Listener");
      form.append("Do you wish to quit?");
      form.setCommandListener(this);

      // Create and add two commands to change the MIDlet state
      quit = new Command("Quit", Command.EXIT, 1);
      form.addCommand(quit);
   }

   /**
    * Called by the Application Manager when the MIDlet is starting or resuming
    * after being paused. In this example it acquires the current Display object
    * and uses it to set the Form object created in the MIDlet constructor as
    * the active Screen to display.
    * @throws MIDletStateChangeException
    */
   protected void startApp() throws MIDletStateChangeException
   {
      Display.getDisplay(this).setCurrent(form);
   }

   /**
    * Called by the MID's Application Manager to pause the MIDlet. A good
    * example of this is when the user receives an incoming phone call whilst
    * playing your game. When they're done the Application Manager will call
    * startApp to resume. For this example we don't need to do anything.
    */
   protected void pauseApp()
   {
   }

   /**
    * Called by the MID's Application Manager when the MIDlet is about to
    * be destroyed (removed from memory). You should take this as an opportunity
    * to clear up any resources and save the game.  For this example we don't
    * need to do anything.
    * @param unconditional if false you have the option of throwing a
    * MIDletStateChangeException to abort the destruction process.
    * @throws MIDletStateChangeException
    */
   protected void destroyApp(boolean unconditional) throws MIDletStateChangeException
   {
   }

   /**
    * The CommandListener interface method called when the user executes
    * a Command, in this case it can only be the quit command we created in the
    * consutructor and added to the Form.
    * @param command The command that was executed.
    * @param displayable The displayable that command was embedded within.
    */
   public void commandAction(Command command, Displayable displayable)
   {
      // output the command on the console
      System.out.println("commandAction(" + command + ", " + displayable +
                         ") called.");
      try
      {
         // compare the command object passed in to our quit command
         if (command == quit)
         {
            destroyApp(true);
            notifyDestroyed();
         }
      }

      catch (MIDletStateChangeException me)
      {
         System.out.println(me + " caught.");
      }
   }
}

