import javax.microedition.midlet.*;
import javax.microedition.lcdui.*;
import java.io.IOException;

/**
 * An example MIDlet that shows how to use an ImageItem
 *
 * @author Martin J. Wells
 */
public class ImageItemTest extends MIDlet implements CommandListener
{
   private Form form;
   private ImageItem imageItem;
   private Command quit;

   /**
    * Constructs the MIDlet by creating a Form object and then populating it
    * with an ImageItem and a quit command.
    */
   public ImageItemTest()
   {
      form = new Form("ImageItem Test");

      Image alienHeadImage = null;
      try
      {
         // Construct the imageitem item and a quit command
         alienHeadImage = Image.createImage("/alienhead.png");
      }
      catch(IOException ioe)
      {
         form.append("unable to load image");
      }

      // construct the image item using our alien head image and append it
      // to the form
      imageItem = new ImageItem(null, alienHeadImage, ImageItem.LAYOUT_RIGHT,
                                null);
      form.append(imageItem);

      quit = new Command("Quit", Command.EXIT, 2);
      form.addCommand(quit);

      form.setCommandListener(this);
   }

   /**
    * Called by the Application Manager when the MIDlet is starting or resuming
    * after being paused. In this example it acquires the current Display object
    * and uses it to set the Form object created in the MIDlet constructor as
    * the active Screen to display.
    * @throws MIDletStateChangeException
    */
   protected void startApp() throws MIDletStateChangeException
   {
      Display.getDisplay(this).setCurrent(form);
   }

   /**
    * Called by the MID's Application Manager to pause the MIDlet. A good
    * example of this is when the user receives an incoming phone call whilst
    * playing your game. When they're done the Application Manager will call
    * startApp to resume. For this example we don't need to do anything.
    */
   protected void pauseApp()
   {
   }

   /**
    * Called by the MID's Application Manager when the MIDlet is about to
    * be destroyed (removed from memory). You should take this as an opportunity
    * to clear up any resources and save the game. For this example we don't
    * need to do anything.
    * @param unconditional if false you have the option of throwing a
    * MIDletStateChangeException to abort the destruction process.
    * @throws MIDletStateChangeException
    */
   protected void destroyApp(boolean unconditional) throws MIDletStateChangeException
   {
   }

   /**
    * The CommandListener interface method called when the user executes a
    * Command, in this case it can only be the quit command we created in the
    * consutructor and added to the Form.
    * @param command
    * @param displayable
    */
   public void commandAction(Command command, Displayable displayable)
   {
      try
      {
         if (command == quit)
         {
            destroyApp(true);
            notifyDestroyed();
         }
      }

      catch (MIDletStateChangeException me)
      {
         System.out.println(me + " caught.");
      }
   }
}

