import javax.microedition.midlet.*;
import javax.microedition.lcdui.*;

/**
 * An demo of the TextBox Screen.
 * @author Martin J. Wells
 */
public class TextBoxTest extends MIDlet implements CommandListener
{
   private TextBox textBox;
   private Alert alert;
   private Command quit;
   private Command go;

   /**
    * MIDlet constructor creates a TextBox Screen and then adds in a go and
    * quit command. We then set this class to be the listener for TextBox
    * commands.
    */
   public TextBoxTest()
   {
      // Setup the UI
      textBox = new TextBox("Enter Thy Name", "Sir ", 20, TextField.ANY);
      go = new Command("Go", Command.SCREEN, 1);
      quit = new Command("Quit", Command.EXIT, 2);
      textBox.addCommand(go);
      textBox.addCommand(quit);
      textBox.setCommandListener(this);
   }

   /**
    * Called by the Application Manager when the MIDlet is starting or resuming
    * after being paused. In this example it acquires the current Display object
    * and uses it to set the Form object created in the MIDlet constructor as
    * the active Screen to display.
    * @throws MIDletStateChangeException
    */
   protected void startApp() throws MIDletStateChangeException
   {
      Display.getDisplay(this).setCurrent(textBox);
   }

   /**
    * Called by the MID's Application Manager to pause the MIDlet. A good
    * example of this is when the user receives an incoming phone call whilst
    * playing your game. When they're done the Application Manager will call
    * startApp to resume. For this example we don't need to do anything.
    */
   protected void pauseApp()
   {
   }

   /**
    * Called by the MID's Application Manager when the MIDlet is about to
    * be destroyed (removed from memory). You should take this as an opportunity
    * to clear up any resources and save the game. For this example we don't
    * need to do anything.
    * @param unconditional if false you have the option of throwing a
    * MIDletStateChangeException to abort the destruction process.
    * @throws MIDletStateChangeException
    */
   protected void destroyApp(boolean unconditional) throws MIDletStateChangeException
   {
   }

   /**
    * The CommandListener interface method called when the user executes a
    * Command, in this case we handle the the quit command we created in the
    * consutructor and added to the Form, as well as the go command, which we
    * use to create and display an Alert.
    * @param command the command that was triggered
    * @param displayable the displayable on which the event occurred
    */
   public void commandAction(Command command, Displayable displayable)
   {
      try
      {
         if (command == quit)
         {
            destroyApp(true);
            notifyDestroyed();
         }

         if (command == go)
         {
            alert = new Alert("", "Greetings " + textBox.getString(), null, AlertType.CONFIRMATION);
            Display.getDisplay(this).setCurrent(alert);
         }

      }

      catch (MIDletStateChangeException me)
      {
         System.out.println(me + " caught.");
      }
   }
}

